jenkins-bot has submitted this change and it was merged.

Change subject: Rename wfIsHipHop() to wfIsHHVM()
......................................................................


Rename wfIsHipHop() to wfIsHHVM()

The former is only really used to refer to the older hphp compiler.
Now all docs pretty much exclusively are referring to HHVM and
that's the project's name going forward.

While we're here, swap HPHP_VERSION for HHVM_VERSION. Either work,
but the latter is more correct.

Only affected extension (in Git or SVN) is GWToolset, fixing in
I3a490ef.

Change-Id: I81e4ce5d14e344e67045050261f91b3c0159f222
---
M includes/GlobalFunctions.php
M includes/Init.php
M includes/specials/SpecialUpload.php
M includes/upload/UploadBase.php
M maintenance/eval.php
5 files changed, 7 insertions(+), 7 deletions(-)

Approvals:
  Aaron Schulz: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/includes/Init.php b/includes/Init.php
index 64431f0..dd5e2d7 100644
--- a/includes/Init.php
+++ b/includes/Init.php
@@ -48,7 +48,7 @@
         * @return bool
         */
        static function isHipHop() {
-               return defined( 'HPHP_VERSION' );
+               return wfIsHHVM();
        }
 
        /**
diff --git a/includes/specials/SpecialUpload.php 
b/includes/specials/SpecialUpload.php
index 09facf4..b79aaa9 100644
--- a/includes/specials/SpecialUpload.php
+++ b/includes/specials/SpecialUpload.php
@@ -812,7 +812,7 @@
                $this->mMaxUploadSize['file'] = UploadBase::getMaxUploadSize( 
'file' );
                # Limit to upload_max_filesize unless we are running under 
HipHop and
                # that setting doesn't exist
-               if ( !wfIsHipHop() ) {
+               if ( !wfIsHHVM() ) {
                        $this->mMaxUploadSize['file'] = min( 
$this->mMaxUploadSize['file'],
                                wfShorthandToInteger( ini_get( 
'upload_max_filesize' ) ),
                                wfShorthandToInteger( ini_get( 'post_max_size' 
) )
diff --git a/includes/upload/UploadBase.php b/includes/upload/UploadBase.php
index 2260241..b162de2 100644
--- a/includes/upload/UploadBase.php
+++ b/includes/upload/UploadBase.php
@@ -105,7 +105,7 @@
                }
 
                # Check php's file_uploads setting
-               return wfIsHipHop() || wfIniGetBool( 'file_uploads' );
+               return wfIsHHVM() || wfIniGetBool( 'file_uploads' );
        }
 
        /**
diff --git a/maintenance/eval.php b/maintenance/eval.php
index abedc61..e03763f 100644
--- a/maintenance/eval.php
+++ b/maintenance/eval.php
@@ -70,7 +70,7 @@
                readline_write_history( $historyFile );
        }
        $val = eval( $line . ";" );
-       if ( wfIsHipHop() || is_null( $val ) ) {
+       if ( wfIsHHVM() || is_null( $val ) ) {
                echo "\n";
        } elseif ( is_string( $val ) || is_numeric( $val ) ) {
                echo "$val\n";

diff --git a/includes/GlobalFunctions.php b/includes/GlobalFunctions.php
index 77c09e5..3a8d077 100644
--- a/includes/GlobalFunctions.php
+++ b/includes/GlobalFunctions.php
@@ -2450,12 +2450,12 @@
 }
 
 /**
  * Check if we are running under HipHop
  *
  * @return Bool
  */
-function wfIsHipHop() {
-       return defined( 'HPHP_VERSION' );
+function wfIsHHVM() {
+       return defined( 'HHVM_VERSION' );
 }
 
 /**
@@ -2450,12 +2450,12 @@
 
 /**
- * Check if we are running under HipHop
+ * Check if we are running under HHVM
  *
  * @return Bool
-- 
To view, visit https://gerrit.wikimedia.org/r/92590
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I81e4ce5d14e344e67045050261f91b3c0159f222
Gerrit-PatchSet: 2
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Chad <[email protected]>
Gerrit-Reviewer: Aaron Schulz <[email protected]>
Gerrit-Reviewer: jenkins-bot

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to